# frozen_string_literal: true

#
# Cookbook:: cronic
# Library:: resource/cronic
#
# Copyright:: 2013, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'chef/resource'
require 'chef/resource/cron'

class Chef
  class Resource
    # A custom resource for managing Cronic-run cron jobs. It would be possible
    # to do this by sub-classing Chef::Resource::Cron and Chef::Provider::Cron,
    # but that would break if/when Chef merges a change to modernize the
    # still-older-style cron resource class.
    class Cronic < Resource
      provides :cronic

      default_action :create

      property :command,
               String,
               name_property: true,
               coerce: proc { |v| "/usr/local/sbin/cronic #{v}" }

      property :user, String, default: 'root'

      %i[minute hour day month weekday].each do |p|
        property p, [Integer, String], default: '*'
      end

      action :create do
        cookbook_file '/usr/local/sbin/cronic' do
          cookbook 'cronic'
          owner 'root'
          group 'root'
          mode '0755'
        end

        cron new_resource.name do
          %i[command minute hour day month weekday user].each do |p|
            send(p, new_resource.send(p))
          end
        end
      end

      action :delete do
        cron new_resource.name do
          %i[command minute hour day month weekday user].each do |p|
            send(p, new_resource.send(p))
          end
          action :delete
        end
      end
    end
  end
end
